import datetime

from mongoengine import *

from .material import Material
from .project import Project
from .usermanagement import Organisation, User
from .workpackage import Workpackage


class CyclicIndirectTensileTest(Document):

    date = DateTimeField(default=datetime.datetime.now,
                         wtf_options={"render_kw": {
                             "step": "60"
                         }})

    standard = StringField(default='TP Asphalt Teil 24')
    
    org_id = LazyReferenceField(Organisation, required=True)
    project_id = LazyReferenceField(Project, required=True)
    workpackage_id = LazyReferenceField(Workpackage, required=False)

    user_id = LazyReferenceField(User,
                                 required=True,
                                 reverse_delete_rule=DO_NOTHING)

    material = LazyReferenceField(Material, required=True)

    tags = ListField(StringField())

    machine = StringField(default=None)

    filehash = StringField(required=True)
    speciment_name = StringField()

    meta = {
        'allow_inheritance': True,
        'index_opts': {},
        'index_background': True,
        'index_cls': False,
        'auto_create_index': True,
        'collection': 'citt',
    }


class CITTSiffnessResults(CyclicIndirectTensileTest):

    #metadata
    f_set = FloatField()
    sigma_set = FloatField()
    T_set = FloatField()

    N_from = IntField()
    N_to = IntField()

    #results
    stiffness = FloatField()
    nu = FloatField()
    phase = FloatField()
    #fit parameter
    ## F
    F_amp = FloatField()
    F_freq = FloatField()
    F_phase = FloatField()
    F_offset = FloatField()
    F_slope = FloatField()
    F_r2 = FloatField()
    ## S1
    s_hor_1_amp = FloatField()
    s_hor_1_freq = FloatField()
    s_hor_1_phase = FloatField()
    s_hor_1_offset = FloatField()
    s_hor_1_slope = FloatField()
    s_hor_1_r2 = FloatField()
    ## S2
    s_hor_2_amp = FloatField()
    s_hor_2_freq = FloatField()
    s_hor_2_phase = FloatField()
    s_hor_2_offset = FloatField()
    s_hor_2_slope = FloatField()
    s_hor_2_r2 = FloatField()
    ## S-Sum
    s_hor_amp = FloatField()
    s_hor_freq = FloatField()
    s_hor_phase = FloatField()
    s_hor_offset = FloatField()
    s_hor_slope = FloatField()
    s_hor_r2 = FloatField()
