import datetime

from mongoengine import *

from .citt import CyclicIndirectTensileTest
from .sheartest import DynamicShearTest


class RawData(Document):

    date = DateTimeField(default=datetime.datetime.now,
                         wtf_options={"render_kw": {
                             "step": "60"
                         }})

    meta = {
        'allow_inheritance': True,
        'index_opts': {},
        'index_background': True,
        'index_cls': False,
        'auto_create_index': True,
        'collection': 'rawdata',
    }


class DataSheartest(RawData):

    #results
    result_id = LazyReferenceField(DynamicShearTest,
                                   required=True,
                                   reverse_delete_rule=CASCADE)

    # data
    time = ListField(FloatField())
    F = ListField(FloatField())
    N = ListField(IntField())
    s_vert_1 = ListField(FloatField())
    s_vert_2 = ListField(FloatField())
    s_vert_sum = ListField(FloatField())
    s_piston = ListField(FloatField())


class CITTSiffness(RawData):

    result = LazyReferenceField(CyclicIndirectTensileTest,
                                required=True,
                                reverse_delete_rule=CASCADE)

    # data
    time = ListField(FloatField())
    F = ListField(FloatField())
    N = ListField(IntField())
    s_hor_1 = ListField(FloatField())
    s_hor_2 = ListField(FloatField())
    s_hor_sum = ListField(FloatField())
    s_piston = ListField(FloatField(), required=False)
