import datetime
from re import T

from mongoengine import *

from .project import Project
from .usermanagement import Organisation, User


class Material(Document):

    date = DateTimeField(default=datetime.datetime.now,
                         wtf_options={"render_kw": {
                             "step": "60"
                         }})

    org_id = LazyReferenceField(Organisation,
                                required=True,
                                reverse_delete_rule=CASCADE)

    project_id = ListField(LazyReferenceField(Project,
                                              required=False,
                                              reverse_delete_rule=CASCADE),
                           required=True)

    user_id = LazyReferenceField(User,
                                 required=False,
                                 reverse_delete_rule=DO_NOTHING)

    tags = ListField(StringField())
    norm = StringField(required=True, default='TP Asphalt Teil 24')

    meta = {
        'allow_inheritance': True,
        'index_opts': {},
        'index_background': True,
        'index_cls': False,
        'auto_create_index': True,
        'collection': 'materials',
        'indexes': [
            [("material", 1)],
            [("name", 1)],
        ]
    }


class Asphalt(Material):

    name = StringField()
    material = StringField()
    bitumen = StringField(required=False)

    young_modulus = DictField()
    fatigue = DictField()


class Bitumen(Material):

    name = StringField()
    material = StringField()

    young_modulus = DictField()


class Bitumenemulsion(Material):

    name = StringField()
    material = StringField()

    young_modulus = DictField()


class Epoxy(Material):
    name = StringField()
    material = StringField()

    young_modulus = DictField()


class Kompaktasphalt(Material):
    name = StringField()


class Dummy(Material):

    name = StringField()
    material = StringField()

    young_modulus = DictField()
