import datetime

from mongoengine import *

from .usermanagement import Organisation, User


class Project(Document):

    name = StringField(required=True)
    name_short = StringField(required=False)
    project_id = StringField(required=True)
    client = StringField(required=False)

    date = DateTimeField(default=datetime.datetime.now,
                         wtf_options={"render_kw": {
                             "step": "60"
                         }})

    org_id = LazyReferenceField(Organisation,
                                required=True,
                                reverse_delete_rule=CASCADE)

    user_id = LazyReferenceField(User,
                                 required=False,
                                 reverse_delete_rule=DO_NOTHING)

    tags = ListField(StringField())

    meta = {
        'allow_inheritance': True,
        'index_opts': {},
        'index_background': True,
        'index_cls': False,
        'auto_create_index': True,
        'collection': 'projects',
        'indexes': [
            [("name_short", 1)],
            [("name", 1)],
            [("project_id", 1)],
        ]
    }
