import datetime

from mongoengine import *

from .material import Material
from .project import Project
from .usermanagement import Organisation, User
from .workpackage import Workpackage


class DynamicShearTest(Document):

    date = DateTimeField(default=datetime.datetime.now,
                         wtf_options={"render_kw": {
                             "step": "60"
                         }})

    org_id = LazyReferenceField(Organisation, required=True)
    project_id = LazyReferenceField(Project, required=True)
    workpackage_id = LazyReferenceField(Workpackage, required=False)

    user_id = LazyReferenceField(User,
                                 required=True,
                                 reverse_delete_rule=DO_NOTHING)

    material1 = LazyReferenceField(Material, required=True)
    material2 = LazyReferenceField(Material, required=True)
    bounding = LazyReferenceField(Material, required=True)

    gap_width = FloatField(default=1.0)

    tags = ListField(StringField())

    standard = StringField(default='TP Asphalt Teil 24')

    machine = StringField(default=None)

    filehash = StringField(required=True)
    speciment_name = StringField()

    meta = {
        'allow_inheritance':
        True,
        'index_opts': {},
        'index_background':
        True,
        'index_cls':
        False,
        'auto_create_index':
        True,
        'collection':
        'sheartest',
        'indexes': [
            [("lab", 1)],
            [("speciment_name", 1)],
            [("project", 1)],
            [("bruch", 1)],
            [("lab", 1), ("project", 1)],
            [("lab", 1), ("project", 1), ("workpackage", 1)],
            [("lab", 1), ("project", 1), ("bounding", 1)],
        ]
    }


class DynamicShearTestExtension(DynamicShearTest):

    #metadata
    f = FloatField(required=True)
    sigma_normal = FloatField(required=True)
    T = FloatField(required=True)
    extension = FloatField(required=True)

    stiffness = FloatField(required=True)
    bruch = BooleanField(required=True)
    #fit parameter
    ## F
    fit_amp_F = FloatField(required=True)
    fit_freq_F = FloatField(required=True)
    fit_phase_F = FloatField(required=True)
    fit_offset_F = FloatField(required=True)
    fit_slope_F = FloatField(required=True)
    ## S1
    fit_amp_s_vert_1 = FloatField(required=True)
    fit_freq_s_vert_1 = FloatField(required=True)
    fit_phase_s_vert_1 = FloatField(required=True)
    fit_offset_s_vert_1 = FloatField(required=True)
    fit_slope_s_vert_1 = FloatField(required=True)
    r2_s_vert_1 = FloatField(required=True)
    ## S2
    fit_amp_s_vert_2 = FloatField(required=True)
    fit_freq_s_vert_2 = FloatField(required=True)
    fit_phase_s_vert_2 = FloatField(required=True)
    fit_offset_s_vert_2 = FloatField(required=True)
    fit_slope_s_vert_2 = FloatField(required=True)
    r2_s_vert_2 = FloatField(required=True)
    ## S-Sum
    fit_amp_s_vert_sum = FloatField(required=True)
    fit_freq_s_vert_sum = FloatField(required=True)
    fit_phase_s_vert_sum = FloatField(required=True)
    fit_offset_s_vert_sum = FloatField(required=True)
    fit_slope_s_vert_sum = FloatField(required=True)
    r2_s_vert_sum = FloatField(required=True)
    ## r2
    r2_F = FloatField(required=True)
    r2_s_vert_1 = FloatField(required=True)
    r2_s_vert_2 = FloatField(required=True)
    r2_s_vert_sum = FloatField(required=True)
